function sim_Testrig
%-----------------------------------------------------------------------------------------
%Funktion zur Simulation des OpenModelica Modells Systemaufbau innerhalb des Packages 
%Testrig und Durchfhrung des Postprocessing.
%-----------------------------------------------------------------------------------------
%% Erzeugen der Executable des Modells falls sie nicht existiert
if ~exist('Testrig.Systemaufbau','file')
    fprintf('\n Das Modell wird kompiliert\n\n');
    omcompilerun('Testrig.mo','Testrig.Systemaufbau',1)
end
%% Festlegung der Simulationsparameter
frequenz  = logspace(-3,1,30);              % Vektor der Anregungsfrequenzen in Hz
anz1 = length(frequenz);                    % Lnge des Frequenzvektors
schrittw  = 2*logspace(-1,-5,anz1);         % Vektor der Schrittweiten in s
toleranz  = 5e-3*schrittw;                  % Vektor der Toleranzen (numerischer Parameter)
perioden  = 5;                              % Anzahl der pro Frequenz zu simulierenden Perioden
stopzeit  = perioden*logspace(3,-1,anz1);   % Vektor der Simulationsdauern in s
%% Starten der Parametervariation
for n = 1:anz1
    % ndern der Parameter im Parameterfile des Modells
    omparameteraendern('Testrig.Systemaufbau_init.txt',{'stop value','step value','tolerance','Sine1.freqHz'},...
        [stopzeit(n),schrittw(n),toleranz(n),frequenz(n)]);
    
    % Starten der Simulation mit den gesetzten Parametern
    omrun('Testrig.Systemaufbau');
    
    % Einlesen der Simulationsergebnisse
    omeinlesen_einzeln('Testrig.Systemaufbau',1);
    
    % Ermittlung der Indices zur Entfernung des Einschwingvorgangs
    laenge1(n) = length(time);
    index1(n)  = laenge1(n)-5100;
    start1(n)  = stopzeit(n)-5e3*schrittw(n);
    index2(n)  = min(find((time-start1(n))>=0));

    % Umbenennung der Variablen
    zeit(:,n)      = time(index1(n):end);
    zkolben(:,n)   = Luftfeder1.z(index1(n):end);
    Fkolben(:,n)   = Luftfeder1.F(index1(n):end);
    pkammer(:,n)   = Luftfeder1.p(index1(n):end);
    Tkammer(:,n)   = Luftfeder1.T(index1(n):end);
    rhokammer(:,n) = Luftfeder1.rho(index1(n):end);

    % Berechnung der Dmpfungsarbeit
    Wfeder(:,n)  = trapz(Luftfeder1.z(index2(n):end),Luftfeder1.F(index2(n):end));  
    
    % Berechnung von Maximal- und Minimalwert der Kolbenkraft
    Fmax(n) = max(Luftfeder1.F(index1(n):end)); % Berechnung der Maximalkraft pro Periode [N]
    Fmin(n) = min(Luftfeder1.F(index1(n):end)); % Berechnung der Minimalkraft pro Periode [N]

    % Graphische Darstellung der Hysteresekurven
    figure(1)
    set(gcf,'color','w')
    plot(1e3*Luftfeder1.z(index1(n):end),Luftfeder1.F(index1(n):end),'linew',3),grid on, hold all
    xlabel('Kolbenweg in mm','fontsize',24,'fontweight','bold')
    ylabel('Kolbenkraft in N','fontsize',24,'fontweight','bold')
    set(gca,'fonts',18)
    title(['Anregungsfrequenz = ',num2str(frequenz(n),'%4.3f'),' Hz'],'fontsize',25,'fontweight','bold')
end
%% Postprocessing: Berechnung des Verlustwinkels 
% Auslesen der frs Postprocessing bentigten Parameter
[zeile,wert] = omparameterfinden('Testrig.Systemaufbau_init.txt',{'Sine1.amplitude',...
    'Luftfeder1.gamma','Luftfeder1.p','Luftfeder1.A','Luftfeder1.V0'});

zamp  = wert(1);                               % Amplitude des Kolbenweges in m
Famp  = (Fmax-Fmin)/2;                         % Amplitude der Kolbenkraft in N
cdyn  = Famp./zamp;                            % dynamische Steifigkeit in N/m
delta = asin(Wfeder./(pi*zamp^2*cdyn))*180/pi; % Verlustwinkel in 

gamma = wert(2);                         % Adiabatenexponent
pinit = wert(3);                         % Anfangsdruck in der Luftfeder in Pa
A     = wert(4);                         % Kolbenflche in m
V     = wert(5);                         % Anfangsvolumen der Luftfeder in m
c1    = gamma*pinit*A^2/V.*ones(1,anz1); % adiabate Steifigkeit in N/m
c0    = c1./gamma;                       % isotherme Steifigkeit in N/m
%% Graphische Darstellung der dynamischen Steifigkeit, des Verlustwinkels und der Dmpfungsarbeit
figure('color','w')
subplot(3,1,1)
semilogx(frequenz,1e-3*cdyn,'linew',3), grid on, hold all
semilogx(frequenz,1e-3*c1,'k',frequenz,1e-3*c0,'k','linew',3)
ylabel('c_d_y_n in N/mm','fonts',24,'fontw','bold')
set(gca,'fonts',18)
subplot(3,1,2)
semilogx(frequenz,delta,'linew',3), grid on, hold all
ylabel('\delta in ','fonts',24,'fontw','bold')
set(gca,'fonts',18)
subplot(3,1,3)
semilogx(frequenz,Wfeder,'linew',3), grid on, hold all
ylabel('W in J','fonts',24,'fontw','bold')
xlabel('Frequenz in Hz','fonts',24,'fontw','bold')
set(gca,'fonts',18)
%% Schreiben der Variablen in den Matlab Workspace
assignin('base','zeit',zeit)
assignin('base','zkolben',zkolben)
assignin('base','Fkolben',Fkolben)
assignin('base','pkammer',Tkammer)
assignin('base','Tkammer',Tkammer)
assignin('base','rhokammer',rhokammer)
assignin('base','Wfeder',Wfeder)
